Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1026)

Unified Diff: ui/compositor/compositor.h

Issue 1808313002: Register surface namespace in BlimpUiContextFactory (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Move SurfaceManager to ContextFactory Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ui/compositor/compositor.h
diff --git a/ui/compositor/compositor.h b/ui/compositor/compositor.h
index 5222b41d956139a64fb231d456bc22ff0d261f54..98f03a941035f2f31275ac693734df431680406f 100644
--- a/ui/compositor/compositor.h
+++ b/ui/compositor/compositor.h
@@ -44,6 +44,7 @@ class LayerTreeHost;
class RendererSettings;
class SharedBitmapManager;
class SurfaceIdAllocator;
+class SurfaceManager;
class TaskGraphRunner;
}
@@ -111,9 +112,12 @@ class COMPOSITOR_EXPORT ContextFactory {
// Gets the task graph runner.
virtual cc::TaskGraphRunner* GetTaskGraphRunner() = 0;
// Creates a Surface ID allocator with a new namespace.
virtual scoped_ptr<cc::SurfaceIdAllocator> CreateSurfaceIdAllocator() = 0;
+ virtual cc::SurfaceManager* GetSurfaceManager() = 0;
+
// Resize the display corresponding to this compositor to a particular size.
virtual void ResizeDisplay(ui::Compositor* compositor,
const gfx::Size& size) = 0;
@@ -111,9 +112,12 @@ class COMPOSITOR_EXPORT ContextFactory {
// Gets the task graph runner.
virtual cc::TaskGraphRunner* GetTaskGraphRunner() = 0;
- // Creates a Surface ID allocator with a new namespace.
+ // Creates a Surface ID allocator with a new namespace, registered with
+ // this context factory's surface manager.
virtual scoped_ptr<cc::SurfaceIdAllocator> CreateSurfaceIdAllocator() = 0;

Powered by Google App Engine
This is Rietveld 408576698